@@ -1,11 +1,11 @@
-# $Id: WebserviceX.pm 381 2005-03-10 03:59:02Z claco $
+# $Id: WebserviceX.pm 393 2005-03-11 01:29:56Z claco $
 package Finance::Currency::Convert::WebserviceX;
 use strict;
 use warnings;
 use vars qw($VERSION);
 use LWP::UserAgent;
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 sub new {
     my $class = shift;
@@ -44,7 +44,7 @@ sub convert {
         return undef;
     } else {
         if ($self->{'response'}->content =~ /<double.*>(.*)<\/double>/i) {
-            return $value*$1;
+            return $value*($1 || 1);
         } else {
             return undef;
         };
